@@ -15,19 +15,15 @@
 
 //! The `swayr` binary.
 
-use clap::{crate_version, Clap};
+use clap::Parser;
 
 /// Windows are sorted urgent first, then windows in LRU order, focused window
 /// last.  Licensed under the GPLv3 (or later).
-#[derive(Clap)]
-#[clap(
-    name = "swayr -- a window switcher (and more) for sway",
-    version = crate_version!(),
-    author = "Tassilo Horn <tsdh@gnu.org>"
-)]
+#[derive(clap::Parser)]
+#[clap(about, version, author)]
 struct Opts {
     #[clap(subcommand)]
-    command: swayr::ipc::SwayrCommand,
+    command: swayr::cmds::SwayrCommand,
 }
 
 fn main() {
